==> kubernetes-model-networking-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkPolicyFluentImpl<A extends NetworkPolicyFluent<A>> extends BaseFluent<A> implements NetworkPolicyFluent<A>{
  public NetworkPolicyFluentImpl() {
  }
  public NetworkPolicyFluentImpl(NetworkPolicy instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private NetworkPolicySpecBuilder spec;
  private NetworkPolicyStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public NetworkPolicyFluent.MetadataNested<A> withNewMetadata() {
    return new NetworkPolicyFluentImpl.MetadataNestedImpl();
  }
  public NetworkPolicyFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new NetworkPolicyFluentImpl.MetadataNestedImpl(item);
  }
  public NetworkPolicyFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public NetworkPolicyFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public NetworkPolicyFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkPolicySpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public NetworkPolicySpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(NetworkPolicySpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new NetworkPolicySpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public NetworkPolicyFluent.SpecNested<A> withNewSpec() {
    return new NetworkPolicyFluentImpl.SpecNestedImpl();
  }
  public NetworkPolicyFluent.SpecNested<A> withNewSpecLike(NetworkPolicySpec item) {
    return new NetworkPolicyFluentImpl.SpecNestedImpl(item);
  }
  public NetworkPolicyFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public NetworkPolicyFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new NetworkPolicySpecBuilder().build());
  }
  public NetworkPolicyFluent.SpecNested<A> editOrNewSpecLike(NetworkPolicySpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkPolicyStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public NetworkPolicyStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(NetworkPolicyStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new NetworkPolicyStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public NetworkPolicyFluent.StatusNested<A> withNewStatus() {
    return new NetworkPolicyFluentImpl.StatusNestedImpl();
  }
  public NetworkPolicyFluent.StatusNested<A> withNewStatusLike(NetworkPolicyStatus item) {
    return new NetworkPolicyFluentImpl.StatusNestedImpl(item);
  }
  public NetworkPolicyFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public NetworkPolicyFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new NetworkPolicyStatusBuilder().build());
  }
  public NetworkPolicyFluent.StatusNested<A> editOrNewStatusLike(NetworkPolicyStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkPolicyFluentImpl that = (NetworkPolicyFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<NetworkPolicyFluent.MetadataNested<N>> implements NetworkPolicyFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) NetworkPolicyFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends NetworkPolicySpecFluentImpl<NetworkPolicyFluent.SpecNested<N>> implements NetworkPolicyFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(NetworkPolicySpec item) {
      this.builder = new NetworkPolicySpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new NetworkPolicySpecBuilder(this);
    }
    NetworkPolicySpecBuilder builder;
    public N and() {
      return (N) NetworkPolicyFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends NetworkPolicyStatusFluentImpl<NetworkPolicyFluent.StatusNested<N>> implements NetworkPolicyFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(NetworkPolicyStatus item) {
      this.builder = new NetworkPolicyStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new NetworkPolicyStatusBuilder(this);
    }
    NetworkPolicyStatusBuilder builder;
    public N and() {
      return (N) NetworkPolicyFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkPolicyFluentImpl<A extends NetworkPolicyFluent<A>> extends BaseFluent<A> implements NetworkPolicyFluent<A>{
  public NetworkPolicyFluentImpl() {
  }
  public NetworkPolicyFluentImpl(NetworkPolicy instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private NetworkPolicySpecBuilder spec;
  private NetworkPolicyStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public NetworkPolicyFluentImpl.MetadataNested<A> withNewMetadata() {
    return new NetworkPolicyFluentImpl.MetadataNestedImpl();
  }
  public NetworkPolicyFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new NetworkPolicyFluentImpl.MetadataNestedImpl(item);
  }
  public NetworkPolicyFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public NetworkPolicyFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public NetworkPolicyFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkPolicySpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public NetworkPolicySpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(NetworkPolicySpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new NetworkPolicySpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public NetworkPolicyFluentImpl.SpecNested<A> withNewSpec() {
    return new NetworkPolicyFluentImpl.SpecNestedImpl();
  }
  public NetworkPolicyFluentImpl.SpecNested<A> withNewSpecLike(NetworkPolicySpec item) {
    return new NetworkPolicyFluentImpl.SpecNestedImpl(item);
  }
  public NetworkPolicyFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public NetworkPolicyFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new NetworkPolicySpecBuilder().build());
  }
  public NetworkPolicyFluentImpl.SpecNested<A> editOrNewSpecLike(NetworkPolicySpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkPolicyStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public NetworkPolicyStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(NetworkPolicyStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new NetworkPolicyStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public NetworkPolicyFluentImpl.StatusNested<A> withNewStatus() {
    return new NetworkPolicyFluentImpl.StatusNestedImpl();
  }
  public NetworkPolicyFluentImpl.StatusNested<A> withNewStatusLike(NetworkPolicyStatus item) {
    return new NetworkPolicyFluentImpl.StatusNestedImpl(item);
  }
  public NetworkPolicyFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public NetworkPolicyFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new NetworkPolicyStatusBuilder().build());
  }
  public NetworkPolicyFluentImpl.StatusNested<A> editOrNewStatusLike(NetworkPolicyStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkPolicyFluentImpl that = (NetworkPolicyFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<NetworkPolicyFluentImpl.MetadataNested<N>> implements NetworkPolicyFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) NetworkPolicyFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends NetworkPolicySpecFluentImpl<NetworkPolicyFluentImpl.SpecNested<N>> implements NetworkPolicyFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(NetworkPolicySpec item) {
      this.builder = new NetworkPolicySpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new NetworkPolicySpecBuilder(this);
    }
    NetworkPolicySpecBuilder builder;
    public N and() {
      return (N) NetworkPolicyFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends NetworkPolicyStatusFluentImpl<NetworkPolicyFluentImpl.StatusNested<N>> implements NetworkPolicyFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(NetworkPolicyStatus item) {
      this.builder = new NetworkPolicyStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new NetworkPolicyStatusBuilder(this);
    }
    NetworkPolicyStatusBuilder builder;
    public N and() {
      return (N) NetworkPolicyFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
